### Name: extractGenes
### Title: Function for extracting the list of genes in common
### Aliases: extractGenes
### Keywords: misc

### ** Examples

data = simulation(n=2000,GammaA=1,GammaB=1,r1=0.5,r2=0.8,DEfirst=1000,DEsecond=800,DEcommon=700)
T<- ratio(n=length(data$Pval1),data1=data$Pval1,data2=data$Pval2,interval=0.01,dir="D:/",name="CompData1Data2",pvalue=TRUE)
BayesianModel<- baymod(n=length(data$Pval1),data1=data$Pval1,data2=data$Pval2,repl=1000,output.ratio=T,dir="D:/")
gene.lists <- extractGenes(output.ratio=T,output.bay=BayesianModel,name.genes=data$names,data1=data$Pval1,data2=data$Pval2,q=NULL)

## The function is currently defined as
function(output.ratio,output.bay,name.genes,data1,data2,q=NULL){

starting.point = (101 - length(output.bay[,1]))/100
threshold = seq(starting.point,1,output.ratio$interval)

#Decision rules:
#1) Maximum for CI not including 1
max.R = max(output.bay[round(round(output.bay[,1],2),1)>1,2])
threshold.max = threshold[output.bay[,2]==max.R]

#2) Rule 2
threshold.2 = max(threshold[round(round(output.bay[,2],2),3)>=2 & round(round(output.bay[,1],2),1)>1])

table.max <- cbind(data1[data1<=threshold.max & data2<=threshold.max],data2[data1<=threshold.max & data2<=threshold.max])
names.max <- name.genes[data1<=threshold.max & data2<=threshold.max]
table.max <- data.frame(names=names.max,Pval1Exp=table.max[,1],Pval2Exp=table.max[,2])

table.2 <- cbind(data1[data1<=threshold.2 & data2<=threshold.2],data2[data1<=threshold.2 & data2<=threshold.2])
names.2 <- name.genes[data1<=threshold.2 & data2<=threshold.2]
table.2 <- data.frame(names=names.2,Pval1Exp=table.2[,1],Pval2Exp=table.2[,2])

if(is.null(q))
{return(list(max = table.max,rule2 = table.2))}

if(!is.null(q))
{table.q <- cbind(data1[data1<=q & data2<=q],data2[data1<=q & data2<=q])
names.q <- name.genes[data1<=q & data2<=q]
table.q <- data.frame(names=names.q,Pval1Exp=table.q[,1],Pval2Exp=table.q[,2])

return(list(max = table.max,rule2 = table.2, q = table.q))}
        }



